
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __LIBMBIM_GLIB_ENUM_TYPES_H__
#define __LIBMBIM_GLIB_ENUM_TYPES_H__
#include "mbim-uuid.h"
#include "mbim-cid.h"
#include "mbim-message.h"
#include "mbim-enums.h"
#include "mbim-tlv.h"

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../libmbim-1.34.0/src/libmbim-glib/mbim-cid.h" */
GType mbim_cid_basic_connect_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_BASIC_CONNECT (mbim_cid_basic_connect_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_BASIC_CONNECT_IS_ENUM__

/**
 * mbim_cid_basic_connect_get_string:
 * @val: a MbimCidBasicConnect.
 *
 * Gets the nickname string for the #MbimCidBasicConnect specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_basic_connect_get_string (MbimCidBasicConnect val);
GType mbim_cid_sms_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_SMS (mbim_cid_sms_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_SMS_IS_ENUM__

/**
 * mbim_cid_sms_get_string:
 * @val: a MbimCidSms.
 *
 * Gets the nickname string for the #MbimCidSms specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_sms_get_string (MbimCidSms val);
GType mbim_cid_ussd_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_USSD (mbim_cid_ussd_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_USSD_IS_ENUM__

/**
 * mbim_cid_ussd_get_string:
 * @val: a MbimCidUssd.
 *
 * Gets the nickname string for the #MbimCidUssd specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_ussd_get_string (MbimCidUssd val);
GType mbim_cid_phonebook_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_PHONEBOOK (mbim_cid_phonebook_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_PHONEBOOK_IS_ENUM__

/**
 * mbim_cid_phonebook_get_string:
 * @val: a MbimCidPhonebook.
 *
 * Gets the nickname string for the #MbimCidPhonebook specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_phonebook_get_string (MbimCidPhonebook val);
GType mbim_cid_stk_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_STK (mbim_cid_stk_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_STK_IS_ENUM__

/**
 * mbim_cid_stk_get_string:
 * @val: a MbimCidStk.
 *
 * Gets the nickname string for the #MbimCidStk specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_stk_get_string (MbimCidStk val);
GType mbim_cid_auth_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_AUTH (mbim_cid_auth_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_AUTH_IS_ENUM__

/**
 * mbim_cid_auth_get_string:
 * @val: a MbimCidAuth.
 *
 * Gets the nickname string for the #MbimCidAuth specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_auth_get_string (MbimCidAuth val);
GType mbim_cid_dss_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_DSS (mbim_cid_dss_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_DSS_IS_ENUM__

/**
 * mbim_cid_dss_get_string:
 * @val: a MbimCidDss.
 *
 * Gets the nickname string for the #MbimCidDss specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_dss_get_string (MbimCidDss val);
GType mbim_cid_ms_firmware_id_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_MS_FIRMWARE_ID (mbim_cid_ms_firmware_id_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_MS_FIRMWARE_ID_IS_ENUM__

/**
 * mbim_cid_ms_firmware_id_get_string:
 * @val: a MbimCidMsFirmwareId.
 *
 * Gets the nickname string for the #MbimCidMsFirmwareId specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_cid_ms_firmware_id_get_string (MbimCidMsFirmwareId val);
GType mbim_cid_ms_host_shutdown_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_MS_HOST_SHUTDOWN (mbim_cid_ms_host_shutdown_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_MS_HOST_SHUTDOWN_IS_ENUM__

/**
 * mbim_cid_ms_host_shutdown_get_string:
 * @val: a MbimCidMsHostShutdown.
 *
 * Gets the nickname string for the #MbimCidMsHostShutdown specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.8
 */
const gchar *mbim_cid_ms_host_shutdown_get_string (MbimCidMsHostShutdown val);
GType mbim_cid_ms_sar_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_MS_SAR (mbim_cid_ms_sar_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_MS_SAR_IS_ENUM__

/**
 * mbim_cid_ms_sar_get_string:
 * @val: a MbimCidMsSar.
 *
 * Gets the nickname string for the #MbimCidMsSar specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_cid_ms_sar_get_string (MbimCidMsSar val);
GType mbim_cid_proxy_control_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_PROXY_CONTROL (mbim_cid_proxy_control_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_PROXY_CONTROL_IS_ENUM__

/**
 * mbim_cid_proxy_control_get_string:
 * @val: a MbimCidProxyControl.
 *
 * Gets the nickname string for the #MbimCidProxyControl specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.10
 */
const gchar *mbim_cid_proxy_control_get_string (MbimCidProxyControl val);
GType mbim_cid_qmi_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_QMI (mbim_cid_qmi_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_QMI_IS_ENUM__

/**
 * mbim_cid_qmi_get_string:
 * @val: a MbimCidQmi.
 *
 * Gets the nickname string for the #MbimCidQmi specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.14
 */
const gchar *mbim_cid_qmi_get_string (MbimCidQmi val);
GType mbim_cid_atds_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_ATDS (mbim_cid_atds_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_ATDS_IS_ENUM__

/**
 * mbim_cid_atds_get_string:
 * @val: a MbimCidAtds.
 *
 * Gets the nickname string for the #MbimCidAtds specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.16
 */
const gchar *mbim_cid_atds_get_string (MbimCidAtds val);
GType mbim_cid_intel_firmware_update_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_INTEL_FIRMWARE_UPDATE (mbim_cid_intel_firmware_update_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_INTEL_FIRMWARE_UPDATE_IS_ENUM__

/**
 * mbim_cid_intel_firmware_update_get_string:
 * @val: a MbimCidIntelFirmwareUpdate.
 *
 * Gets the nickname string for the #MbimCidIntelFirmwareUpdate specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.16
 */
const gchar *mbim_cid_intel_firmware_update_get_string (MbimCidIntelFirmwareUpdate val);
GType mbim_cid_qdu_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_QDU (mbim_cid_qdu_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_QDU_IS_ENUM__

/**
 * mbim_cid_qdu_get_string:
 * @val: a MbimCidQdu.
 *
 * Gets the nickname string for the #MbimCidQdu specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_cid_qdu_get_string (MbimCidQdu val);
GType mbim_cid_ms_basic_connect_extensions_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_MS_BASIC_CONNECT_EXTENSIONS (mbim_cid_ms_basic_connect_extensions_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_MS_BASIC_CONNECT_EXTENSIONS_IS_ENUM__

/**
 * mbim_cid_ms_basic_connect_extensions_get_string:
 * @val: a MbimCidMsBasicConnectExtensions.
 *
 * Gets the nickname string for the #MbimCidMsBasicConnectExtensions specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.18
 */
const gchar *mbim_cid_ms_basic_connect_extensions_get_string (MbimCidMsBasicConnectExtensions val);
GType mbim_cid_ms_uicc_low_level_access_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_MS_UICC_LOW_LEVEL_ACCESS (mbim_cid_ms_uicc_low_level_access_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_MS_UICC_LOW_LEVEL_ACCESS_IS_ENUM__

/**
 * mbim_cid_ms_uicc_low_level_access_get_string:
 * @val: a MbimCidMsUiccLowLevelAccess.
 *
 * Gets the nickname string for the #MbimCidMsUiccLowLevelAccess specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_cid_ms_uicc_low_level_access_get_string (MbimCidMsUiccLowLevelAccess val);
GType mbim_cid_quectel_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_QUECTEL (mbim_cid_quectel_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_QUECTEL_IS_ENUM__

/**
 * mbim_cid_quectel_get_string:
 * @val: a MbimCidQuectel.
 *
 * Gets the nickname string for the #MbimCidQuectel specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26.2
 */
const gchar *mbim_cid_quectel_get_string (MbimCidQuectel val);
GType mbim_cid_intel_thermal_rf_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_INTEL_THERMAL_RF (mbim_cid_intel_thermal_rf_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_INTEL_THERMAL_RF_IS_ENUM__

/**
 * mbim_cid_intel_thermal_rf_get_string:
 * @val: a MbimCidIntelThermalRf.
 *
 * Gets the nickname string for the #MbimCidIntelThermalRf specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_cid_intel_thermal_rf_get_string (MbimCidIntelThermalRf val);
GType mbim_cid_ms_voice_extensions_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_MS_VOICE_EXTENSIONS (mbim_cid_ms_voice_extensions_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_MS_VOICE_EXTENSIONS_IS_ENUM__

/**
 * mbim_cid_ms_voice_extensions_get_string:
 * @val: a MbimCidMsVoiceExtensions.
 *
 * Gets the nickname string for the #MbimCidMsVoiceExtensions specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_cid_ms_voice_extensions_get_string (MbimCidMsVoiceExtensions val);
GType mbim_cid_intel_mutual_authentication_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_INTEL_MUTUAL_AUTHENTICATION (mbim_cid_intel_mutual_authentication_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_INTEL_MUTUAL_AUTHENTICATION_IS_ENUM__

/**
 * mbim_cid_intel_mutual_authentication_get_string:
 * @val: a MbimCidIntelMutualAuthentication.
 *
 * Gets the nickname string for the #MbimCidIntelMutualAuthentication specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_cid_intel_mutual_authentication_get_string (MbimCidIntelMutualAuthentication val);
GType mbim_cid_intel_tools_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_INTEL_TOOLS (mbim_cid_intel_tools_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_INTEL_TOOLS_IS_ENUM__

/**
 * mbim_cid_intel_tools_get_string:
 * @val: a MbimCidIntelTools.
 *
 * Gets the nickname string for the #MbimCidIntelTools specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_cid_intel_tools_get_string (MbimCidIntelTools val);
GType mbim_cid_google_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_GOOGLE (mbim_cid_google_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_GOOGLE_IS_ENUM__

/**
 * mbim_cid_google_get_string:
 * @val: a MbimCidGoogle.
 *
 * Gets the nickname string for the #MbimCidGoogle specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_cid_google_get_string (MbimCidGoogle val);
GType mbim_cid_fibocom_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_FIBOCOM (mbim_cid_fibocom_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_FIBOCOM_IS_ENUM__

/**
 * mbim_cid_fibocom_get_string:
 * @val: a MbimCidFibocom.
 *
 * Gets the nickname string for the #MbimCidFibocom specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.32
 */
const gchar *mbim_cid_fibocom_get_string (MbimCidFibocom val);
GType mbim_cid_compal_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_COMPAL (mbim_cid_compal_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_COMPAL_IS_ENUM__

/**
 * mbim_cid_compal_get_string:
 * @val: a MbimCidCompal.
 *
 * Gets the nickname string for the #MbimCidCompal specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.32
 */
const gchar *mbim_cid_compal_get_string (MbimCidCompal val);
GType mbim_cid_intel_at_tunnel_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CID_INTEL_AT_TUNNEL (mbim_cid_intel_at_tunnel_get_type ())

/* Define type-specific symbols */
#define __MBIM_CID_INTEL_AT_TUNNEL_IS_ENUM__

/**
 * mbim_cid_intel_at_tunnel_get_string:
 * @val: a MbimCidIntelAtTunnel.
 *
 * Gets the nickname string for the #MbimCidIntelAtTunnel specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.34
 */
const gchar *mbim_cid_intel_at_tunnel_get_string (MbimCidIntelAtTunnel val);

/* enumerations from "../libmbim-1.34.0/src/libmbim-glib/mbim-enums.h" */
GType mbim_device_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DEVICE_TYPE (mbim_device_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_DEVICE_TYPE_IS_ENUM__

/**
 * mbim_device_type_get_string:
 * @val: a MbimDeviceType.
 *
 * Gets the nickname string for the #MbimDeviceType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_device_type_get_string (MbimDeviceType val);
GType mbim_voice_class_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_VOICE_CLASS (mbim_voice_class_get_type ())

/* Define type-specific symbols */
#define __MBIM_VOICE_CLASS_IS_ENUM__

/**
 * mbim_voice_class_get_string:
 * @val: a MbimVoiceClass.
 *
 * Gets the nickname string for the #MbimVoiceClass specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_voice_class_get_string (MbimVoiceClass val);
GType mbim_subscriber_ready_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SUBSCRIBER_READY_STATE (mbim_subscriber_ready_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_SUBSCRIBER_READY_STATE_IS_ENUM__

/**
 * mbim_subscriber_ready_state_get_string:
 * @val: a MbimSubscriberReadyState.
 *
 * Gets the nickname string for the #MbimSubscriberReadyState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_subscriber_ready_state_get_string (MbimSubscriberReadyState val);
GType mbim_radio_switch_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_RADIO_SWITCH_STATE (mbim_radio_switch_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_RADIO_SWITCH_STATE_IS_ENUM__

/**
 * mbim_radio_switch_state_get_string:
 * @val: a MbimRadioSwitchState.
 *
 * Gets the nickname string for the #MbimRadioSwitchState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_radio_switch_state_get_string (MbimRadioSwitchState val);
GType mbim_pin_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PIN_TYPE (mbim_pin_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_PIN_TYPE_IS_ENUM__

/**
 * mbim_pin_type_get_string:
 * @val: a MbimPinType.
 *
 * Gets the nickname string for the #MbimPinType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_pin_type_get_string (MbimPinType val);
GType mbim_pin_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PIN_STATE (mbim_pin_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_PIN_STATE_IS_ENUM__

/**
 * mbim_pin_state_get_string:
 * @val: a MbimPinState.
 *
 * Gets the nickname string for the #MbimPinState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_pin_state_get_string (MbimPinState val);
GType mbim_pin_operation_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PIN_OPERATION (mbim_pin_operation_get_type ())

/* Define type-specific symbols */
#define __MBIM_PIN_OPERATION_IS_ENUM__

/**
 * mbim_pin_operation_get_string:
 * @val: a MbimPinOperation.
 *
 * Gets the nickname string for the #MbimPinOperation specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_pin_operation_get_string (MbimPinOperation val);
GType mbim_pin_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PIN_MODE (mbim_pin_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_PIN_MODE_IS_ENUM__

/**
 * mbim_pin_mode_get_string:
 * @val: a MbimPinMode.
 *
 * Gets the nickname string for the #MbimPinMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_pin_mode_get_string (MbimPinMode val);
GType mbim_pin_format_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PIN_FORMAT (mbim_pin_format_get_type ())

/* Define type-specific symbols */
#define __MBIM_PIN_FORMAT_IS_ENUM__

/**
 * mbim_pin_format_get_string:
 * @val: a MbimPinFormat.
 *
 * Gets the nickname string for the #MbimPinFormat specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_pin_format_get_string (MbimPinFormat val);
GType mbim_access_media_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_ACCESS_MEDIA_TYPE (mbim_access_media_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_ACCESS_MEDIA_TYPE_IS_ENUM__

/**
 * mbim_access_media_type_get_string:
 * @val: a MbimAccessMediaType.
 *
 * Gets the nickname string for the #MbimAccessMediaType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_access_media_type_get_string (MbimAccessMediaType val);
GType mbim_visible_providers_action_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_VISIBLE_PROVIDERS_ACTION (mbim_visible_providers_action_get_type ())

/* Define type-specific symbols */
#define __MBIM_VISIBLE_PROVIDERS_ACTION_IS_ENUM__

/**
 * mbim_visible_providers_action_get_string:
 * @val: a MbimVisibleProvidersAction.
 *
 * Gets the nickname string for the #MbimVisibleProvidersAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.2
 */
const gchar *mbim_visible_providers_action_get_string (MbimVisibleProvidersAction val);
GType mbim_nw_error_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_NW_ERROR (mbim_nw_error_get_type ())

/* Define type-specific symbols */
#define __MBIM_NW_ERROR_IS_ENUM__

/**
 * mbim_nw_error_get_string:
 * @val: a MbimNwError.
 *
 * Gets the nickname string for the #MbimNwError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_nw_error_get_string (MbimNwError val);
GType mbim_register_action_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_REGISTER_ACTION (mbim_register_action_get_type ())

/* Define type-specific symbols */
#define __MBIM_REGISTER_ACTION_IS_ENUM__

/**
 * mbim_register_action_get_string:
 * @val: a MbimRegisterAction.
 *
 * Gets the nickname string for the #MbimRegisterAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_register_action_get_string (MbimRegisterAction val);
GType mbim_register_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_REGISTER_STATE (mbim_register_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_REGISTER_STATE_IS_ENUM__

/**
 * mbim_register_state_get_string:
 * @val: a MbimRegisterState.
 *
 * Gets the nickname string for the #MbimRegisterState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_register_state_get_string (MbimRegisterState val);
GType mbim_register_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_REGISTER_MODE (mbim_register_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_REGISTER_MODE_IS_ENUM__

/**
 * mbim_register_mode_get_string:
 * @val: a MbimRegisterMode.
 *
 * Gets the nickname string for the #MbimRegisterMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_register_mode_get_string (MbimRegisterMode val);
GType mbim_wake_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_WAKE_TYPE (mbim_wake_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_WAKE_TYPE_IS_ENUM__

/**
 * mbim_wake_type_get_string:
 * @val: a MbimWakeType.
 *
 * Gets the nickname string for the #MbimWakeType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_wake_type_get_string (MbimWakeType val);
GType mbim_packet_service_action_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PACKET_SERVICE_ACTION (mbim_packet_service_action_get_type ())

/* Define type-specific symbols */
#define __MBIM_PACKET_SERVICE_ACTION_IS_ENUM__

/**
 * mbim_packet_service_action_get_string:
 * @val: a MbimPacketServiceAction.
 *
 * Gets the nickname string for the #MbimPacketServiceAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_packet_service_action_get_string (MbimPacketServiceAction val);
GType mbim_packet_service_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PACKET_SERVICE_STATE (mbim_packet_service_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_PACKET_SERVICE_STATE_IS_ENUM__

/**
 * mbim_packet_service_state_get_string:
 * @val: a MbimPacketServiceState.
 *
 * Gets the nickname string for the #MbimPacketServiceState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_packet_service_state_get_string (MbimPacketServiceState val);
GType mbim_activation_command_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_ACTIVATION_COMMAND (mbim_activation_command_get_type ())

/* Define type-specific symbols */
#define __MBIM_ACTIVATION_COMMAND_IS_ENUM__

/**
 * mbim_activation_command_get_string:
 * @val: a MbimActivationCommand.
 *
 * Gets the nickname string for the #MbimActivationCommand specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_activation_command_get_string (MbimActivationCommand val);
GType mbim_compression_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_COMPRESSION (mbim_compression_get_type ())

/* Define type-specific symbols */
#define __MBIM_COMPRESSION_IS_ENUM__

/**
 * mbim_compression_get_string:
 * @val: a MbimCompression.
 *
 * Gets the nickname string for the #MbimCompression specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_compression_get_string (MbimCompression val);
GType mbim_auth_protocol_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_AUTH_PROTOCOL (mbim_auth_protocol_get_type ())

/* Define type-specific symbols */
#define __MBIM_AUTH_PROTOCOL_IS_ENUM__

/**
 * mbim_auth_protocol_get_string:
 * @val: a MbimAuthProtocol.
 *
 * Gets the nickname string for the #MbimAuthProtocol specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_auth_protocol_get_string (MbimAuthProtocol val);
GType mbim_context_ip_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_IP_TYPE (mbim_context_ip_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_IP_TYPE_IS_ENUM__

/**
 * mbim_context_ip_type_get_string:
 * @val: a MbimContextIpType.
 *
 * Gets the nickname string for the #MbimContextIpType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_context_ip_type_get_string (MbimContextIpType val);
GType mbim_activation_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_ACTIVATION_STATE (mbim_activation_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_ACTIVATION_STATE_IS_ENUM__

/**
 * mbim_activation_state_get_string:
 * @val: a MbimActivationState.
 *
 * Gets the nickname string for the #MbimActivationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_activation_state_get_string (MbimActivationState val);
GType mbim_voice_call_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_VOICE_CALL_STATE (mbim_voice_call_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_VOICE_CALL_STATE_IS_ENUM__

/**
 * mbim_voice_call_state_get_string:
 * @val: a MbimVoiceCallState.
 *
 * Gets the nickname string for the #MbimVoiceCallState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_voice_call_state_get_string (MbimVoiceCallState val);
GType mbim_sms_storage_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_STORAGE_STATE (mbim_sms_storage_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_STORAGE_STATE_IS_ENUM__

/**
 * mbim_sms_storage_state_get_string:
 * @val: a MbimSmsStorageState.
 *
 * Gets the nickname string for the #MbimSmsStorageState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_sms_storage_state_get_string (MbimSmsStorageState val);
GType mbim_sms_format_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_FORMAT (mbim_sms_format_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_FORMAT_IS_ENUM__

/**
 * mbim_sms_format_get_string:
 * @val: a MbimSmsFormat.
 *
 * Gets the nickname string for the #MbimSmsFormat specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_sms_format_get_string (MbimSmsFormat val);
GType mbim_sms_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_FLAG (mbim_sms_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_FLAG_IS_ENUM__

/**
 * mbim_sms_flag_get_string:
 * @val: a MbimSmsFlag.
 *
 * Gets the nickname string for the #MbimSmsFlag specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_sms_flag_get_string (MbimSmsFlag val);
GType mbim_sms_cdma_lang_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_CDMA_LANG (mbim_sms_cdma_lang_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_CDMA_LANG_IS_ENUM__

/**
 * mbim_sms_cdma_lang_get_string:
 * @val: a MbimSmsCdmaLang.
 *
 * Gets the nickname string for the #MbimSmsCdmaLang specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_sms_cdma_lang_get_string (MbimSmsCdmaLang val);
GType mbim_sms_cdma_encoding_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_CDMA_ENCODING (mbim_sms_cdma_encoding_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_CDMA_ENCODING_IS_ENUM__

/**
 * mbim_sms_cdma_encoding_get_string:
 * @val: a MbimSmsCdmaEncoding.
 *
 * Gets the nickname string for the #MbimSmsCdmaEncoding specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_sms_cdma_encoding_get_string (MbimSmsCdmaEncoding val);
GType mbim_sms_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SMS_STATUS (mbim_sms_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_SMS_STATUS_IS_ENUM__

/**
 * mbim_sms_status_get_string:
 * @val: a MbimSmsStatus.
 *
 * Gets the nickname string for the #MbimSmsStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_sms_status_get_string (MbimSmsStatus val);
GType mbim_ussd_action_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_USSD_ACTION (mbim_ussd_action_get_type ())

/* Define type-specific symbols */
#define __MBIM_USSD_ACTION_IS_ENUM__

/**
 * mbim_ussd_action_get_string:
 * @val: a MbimUssdAction.
 *
 * Gets the nickname string for the #MbimUssdAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_ussd_action_get_string (MbimUssdAction val);
GType mbim_ussd_response_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_USSD_RESPONSE (mbim_ussd_response_get_type ())

/* Define type-specific symbols */
#define __MBIM_USSD_RESPONSE_IS_ENUM__

/**
 * mbim_ussd_response_get_string:
 * @val: a MbimUssdResponse.
 *
 * Gets the nickname string for the #MbimUssdResponse specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_ussd_response_get_string (MbimUssdResponse val);
GType mbim_ussd_session_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_USSD_SESSION_STATE (mbim_ussd_session_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_USSD_SESSION_STATE_IS_ENUM__

/**
 * mbim_ussd_session_state_get_string:
 * @val: a MbimUssdSessionState.
 *
 * Gets the nickname string for the #MbimUssdSessionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_ussd_session_state_get_string (MbimUssdSessionState val);
GType mbim_phonebook_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PHONEBOOK_STATE (mbim_phonebook_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_PHONEBOOK_STATE_IS_ENUM__

/**
 * mbim_phonebook_state_get_string:
 * @val: a MbimPhonebookState.
 *
 * Gets the nickname string for the #MbimPhonebookState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_phonebook_state_get_string (MbimPhonebookState val);
GType mbim_phonebook_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PHONEBOOK_FLAG (mbim_phonebook_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_PHONEBOOK_FLAG_IS_ENUM__

/**
 * mbim_phonebook_flag_get_string:
 * @val: a MbimPhonebookFlag.
 *
 * Gets the nickname string for the #MbimPhonebookFlag specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_phonebook_flag_get_string (MbimPhonebookFlag val);
GType mbim_phonebook_write_flag_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PHONEBOOK_WRITE_FLAG (mbim_phonebook_write_flag_get_type ())

/* Define type-specific symbols */
#define __MBIM_PHONEBOOK_WRITE_FLAG_IS_ENUM__

/**
 * mbim_phonebook_write_flag_get_string:
 * @val: a MbimPhonebookWriteFlag.
 *
 * Gets the nickname string for the #MbimPhonebookWriteFlag specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_phonebook_write_flag_get_string (MbimPhonebookWriteFlag val);
GType mbim_stk_pac_profile_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_STK_PAC_PROFILE (mbim_stk_pac_profile_get_type ())

/* Define type-specific symbols */
#define __MBIM_STK_PAC_PROFILE_IS_ENUM__

/**
 * mbim_stk_pac_profile_get_string:
 * @val: a MbimStkPacProfile.
 *
 * Gets the nickname string for the #MbimStkPacProfile specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_stk_pac_profile_get_string (MbimStkPacProfile val);
GType mbim_stk_pac_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_STK_PAC_TYPE (mbim_stk_pac_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_STK_PAC_TYPE_IS_ENUM__

/**
 * mbim_stk_pac_type_get_string:
 * @val: a MbimStkPacType.
 *
 * Gets the nickname string for the #MbimStkPacType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_stk_pac_type_get_string (MbimStkPacType val);
GType mbim_network_idle_hint_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_NETWORK_IDLE_HINT_STATE (mbim_network_idle_hint_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_NETWORK_IDLE_HINT_STATE_IS_ENUM__

/**
 * mbim_network_idle_hint_state_get_string:
 * @val: a MbimNetworkIdleHintState.
 *
 * Gets the nickname string for the #MbimNetworkIdleHintState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_network_idle_hint_state_get_string (MbimNetworkIdleHintState val);
GType mbim_emergency_mode_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_EMERGENCY_MODE_STATE (mbim_emergency_mode_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_EMERGENCY_MODE_STATE_IS_ENUM__

/**
 * mbim_emergency_mode_state_get_string:
 * @val: a MbimEmergencyModeState.
 *
 * Gets the nickname string for the #MbimEmergencyModeState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_emergency_mode_state_get_string (MbimEmergencyModeState val);
GType mbim_dss_link_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DSS_LINK_STATE (mbim_dss_link_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_DSS_LINK_STATE_IS_ENUM__

/**
 * mbim_dss_link_state_get_string:
 * @val: a MbimDssLinkState.
 *
 * Gets the nickname string for the #MbimDssLinkState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.4
 */
const gchar *mbim_dss_link_state_get_string (MbimDssLinkState val);
GType mbim_qdu_session_action_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_SESSION_ACTION (mbim_qdu_session_action_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_SESSION_ACTION_IS_ENUM__

/**
 * mbim_qdu_session_action_get_string:
 * @val: a MbimQduSessionAction.
 *
 * Gets the nickname string for the #MbimQduSessionAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_qdu_session_action_get_string (MbimQduSessionAction val);
GType mbim_qdu_session_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_SESSION_TYPE (mbim_qdu_session_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_SESSION_TYPE_IS_ENUM__

/**
 * mbim_qdu_session_type_get_string:
 * @val: a MbimQduSessionType.
 *
 * Gets the nickname string for the #MbimQduSessionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_qdu_session_type_get_string (MbimQduSessionType val);
GType mbim_qdu_session_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_SESSION_STATUS (mbim_qdu_session_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_SESSION_STATUS_IS_ENUM__

/**
 * mbim_qdu_session_status_get_string:
 * @val: a MbimQduSessionStatus.
 *
 * Gets the nickname string for the #MbimQduSessionStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_qdu_session_status_get_string (MbimQduSessionStatus val);
GType mbim_qdu_session_result_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_SESSION_RESULT (mbim_qdu_session_result_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_SESSION_RESULT_IS_ENUM__

/**
 * mbim_qdu_session_result_get_string:
 * @val: a MbimQduSessionResult.
 *
 * Gets the nickname string for the #MbimQduSessionResult specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_qdu_session_result_get_string (MbimQduSessionResult val);
GType mbim_qdu_file_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_FILE_TYPE (mbim_qdu_file_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_FILE_TYPE_IS_ENUM__

/**
 * mbim_qdu_file_type_get_string:
 * @val: a MbimQduFileType.
 *
 * Gets the nickname string for the #MbimQduFileType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_qdu_file_type_get_string (MbimQduFileType val);
GType mbim_qdu_quectel_reboot_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_QUECTEL_REBOOT_TYPE (mbim_qdu_quectel_reboot_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_QUECTEL_REBOOT_TYPE_IS_ENUM__

/**
 * mbim_qdu_quectel_reboot_type_get_string:
 * @val: a MbimQduQuectelRebootType.
 *
 * Gets the nickname string for the #MbimQduQuectelRebootType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_qdu_quectel_reboot_type_get_string (MbimQduQuectelRebootType val);
GType mbim_qdu_quectel_version_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QDU_QUECTEL_VERSION_TYPE (mbim_qdu_quectel_version_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_QDU_QUECTEL_VERSION_TYPE_IS_ENUM__

/**
 * mbim_qdu_quectel_version_type_get_string:
 * @val: a MbimQduQuectelVersionType.
 *
 * Gets the nickname string for the #MbimQduQuectelVersionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_qdu_quectel_version_type_get_string (MbimQduQuectelVersionType val);
GType mbim_atds_rat_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_ATDS_RAT_MODE (mbim_atds_rat_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_ATDS_RAT_MODE_IS_ENUM__

/**
 * mbim_atds_rat_mode_get_string:
 * @val: a MbimAtdsRatMode.
 *
 * Gets the nickname string for the #MbimAtdsRatMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.16
 */
const gchar *mbim_atds_rat_mode_get_string (MbimAtdsRatMode val);
GType mbim_atds_provider_plmn_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_ATDS_PROVIDER_PLMN_MODE (mbim_atds_provider_plmn_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_ATDS_PROVIDER_PLMN_MODE_IS_ENUM__

/**
 * mbim_atds_provider_plmn_mode_get_string:
 * @val: a MbimAtdsProviderPlmnMode.
 *
 * Gets the nickname string for the #MbimAtdsProviderPlmnMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.16
 */
const gchar *mbim_atds_provider_plmn_mode_get_string (MbimAtdsProviderPlmnMode val);
GType mbim_pco_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_PCO_TYPE (mbim_pco_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_PCO_TYPE_IS_ENUM__

/**
 * mbim_pco_type_get_string:
 * @val: a MbimPcoType.
 *
 * Gets the nickname string for the #MbimPcoType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.18
 */
const gchar *mbim_pco_type_get_string (MbimPcoType val);
GType mbim_lte_attach_context_operation_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_LTE_ATTACH_CONTEXT_OPERATION (mbim_lte_attach_context_operation_get_type ())

/* Define type-specific symbols */
#define __MBIM_LTE_ATTACH_CONTEXT_OPERATION_IS_ENUM__

/**
 * mbim_lte_attach_context_operation_get_string:
 * @val: a MbimLteAttachContextOperation.
 *
 * Gets the nickname string for the #MbimLteAttachContextOperation specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.18
 */
const gchar *mbim_lte_attach_context_operation_get_string (MbimLteAttachContextOperation val);
GType mbim_lte_attach_context_roaming_control_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_LTE_ATTACH_CONTEXT_ROAMING_CONTROL (mbim_lte_attach_context_roaming_control_get_type ())

/* Define type-specific symbols */
#define __MBIM_LTE_ATTACH_CONTEXT_ROAMING_CONTROL_IS_ENUM__

/**
 * mbim_lte_attach_context_roaming_control_get_string:
 * @val: a MbimLteAttachContextRoamingControl.
 *
 * Gets the nickname string for the #MbimLteAttachContextRoamingControl specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.18
 */
const gchar *mbim_lte_attach_context_roaming_control_get_string (MbimLteAttachContextRoamingControl val);
GType mbim_context_source_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_SOURCE (mbim_context_source_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_SOURCE_IS_ENUM__

/**
 * mbim_context_source_get_string:
 * @val: a MbimContextSource.
 *
 * Gets the nickname string for the #MbimContextSource specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.18
 */
const gchar *mbim_context_source_get_string (MbimContextSource val);
GType mbim_lte_attach_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_LTE_ATTACH_STATE (mbim_lte_attach_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_LTE_ATTACH_STATE_IS_ENUM__

/**
 * mbim_lte_attach_state_get_string:
 * @val: a MbimLteAttachState.
 *
 * Gets the nickname string for the #MbimLteAttachState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.18
 */
const gchar *mbim_lte_attach_state_get_string (MbimLteAttachState val);
GType mbim_sar_control_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SAR_CONTROL_MODE (mbim_sar_control_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_SAR_CONTROL_MODE_IS_ENUM__

/**
 * mbim_sar_control_mode_get_string:
 * @val: a MbimSarControlMode.
 *
 * Gets the nickname string for the #MbimSarControlMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_sar_control_mode_get_string (MbimSarControlMode val);
GType mbim_sar_backoff_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SAR_BACKOFF_STATE (mbim_sar_backoff_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_SAR_BACKOFF_STATE_IS_ENUM__

/**
 * mbim_sar_backoff_state_get_string:
 * @val: a MbimSarBackoffState.
 *
 * Gets the nickname string for the #MbimSarBackoffState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_sar_backoff_state_get_string (MbimSarBackoffState val);
GType mbim_sar_wifi_hardware_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SAR_WIFI_HARDWARE_STATE (mbim_sar_wifi_hardware_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_SAR_WIFI_HARDWARE_STATE_IS_ENUM__

/**
 * mbim_sar_wifi_hardware_state_get_string:
 * @val: a MbimSarWifiHardwareState.
 *
 * Gets the nickname string for the #MbimSarWifiHardwareState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_sar_wifi_hardware_state_get_string (MbimSarWifiHardwareState val);
GType mbim_transmission_notification_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_TRANSMISSION_NOTIFICATION_STATUS (mbim_transmission_notification_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_TRANSMISSION_NOTIFICATION_STATUS_IS_ENUM__

/**
 * mbim_transmission_notification_status_get_string:
 * @val: a MbimTransmissionNotificationStatus.
 *
 * Gets the nickname string for the #MbimTransmissionNotificationStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_transmission_notification_status_get_string (MbimTransmissionNotificationStatus val);
GType mbim_transmission_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_TRANSMISSION_STATE (mbim_transmission_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_TRANSMISSION_STATE_IS_ENUM__

/**
 * mbim_transmission_state_get_string:
 * @val: a MbimTransmissionState.
 *
 * Gets the nickname string for the #MbimTransmissionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_transmission_state_get_string (MbimTransmissionState val);
GType mbim_uicc_slot_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_SLOT_STATE (mbim_uicc_slot_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_SLOT_STATE_IS_ENUM__

/**
 * mbim_uicc_slot_state_get_string:
 * @val: a MbimUiccSlotState.
 *
 * Gets the nickname string for the #MbimUiccSlotState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_uicc_slot_state_get_string (MbimUiccSlotState val);
GType mbim_uicc_secure_messaging_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_SECURE_MESSAGING (mbim_uicc_secure_messaging_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_SECURE_MESSAGING_IS_ENUM__

/**
 * mbim_uicc_secure_messaging_get_string:
 * @val: a MbimUiccSecureMessaging.
 *
 * Gets the nickname string for the #MbimUiccSecureMessaging specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_uicc_secure_messaging_get_string (MbimUiccSecureMessaging val);
GType mbim_uicc_class_byte_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_CLASS_BYTE_TYPE (mbim_uicc_class_byte_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_CLASS_BYTE_TYPE_IS_ENUM__

/**
 * mbim_uicc_class_byte_type_get_string:
 * @val: a MbimUiccClassByteType.
 *
 * Gets the nickname string for the #MbimUiccClassByteType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_uicc_class_byte_type_get_string (MbimUiccClassByteType val);
GType mbim_uicc_pass_through_action_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_PASS_THROUGH_ACTION (mbim_uicc_pass_through_action_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_PASS_THROUGH_ACTION_IS_ENUM__

/**
 * mbim_uicc_pass_through_action_get_string:
 * @val: a MbimUiccPassThroughAction.
 *
 * Gets the nickname string for the #MbimUiccPassThroughAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_uicc_pass_through_action_get_string (MbimUiccPassThroughAction val);
GType mbim_uicc_pass_through_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_PASS_THROUGH_STATUS (mbim_uicc_pass_through_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_PASS_THROUGH_STATUS_IS_ENUM__

/**
 * mbim_uicc_pass_through_status_get_string:
 * @val: a MbimUiccPassThroughStatus.
 *
 * Gets the nickname string for the #MbimUiccPassThroughStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26
 */
const gchar *mbim_uicc_pass_through_status_get_string (MbimUiccPassThroughStatus val);
GType mbim_modem_configuration_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_MODEM_CONFIGURATION_STATUS (mbim_modem_configuration_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_MODEM_CONFIGURATION_STATUS_IS_ENUM__

/**
 * mbim_modem_configuration_status_get_string:
 * @val: a MbimModemConfigurationStatus.
 *
 * Gets the nickname string for the #MbimModemConfigurationStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_modem_configuration_status_get_string (MbimModemConfigurationStatus val);
GType mbim_context_roaming_control_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_ROAMING_CONTROL (mbim_context_roaming_control_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_ROAMING_CONTROL_IS_ENUM__

/**
 * mbim_context_roaming_control_get_string:
 * @val: a MbimContextRoamingControl.
 *
 * Gets the nickname string for the #MbimContextRoamingControl specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_context_roaming_control_get_string (MbimContextRoamingControl val);
GType mbim_context_media_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_MEDIA_TYPE (mbim_context_media_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_MEDIA_TYPE_IS_ENUM__

/**
 * mbim_context_media_type_get_string:
 * @val: a MbimContextMediaType.
 *
 * Gets the nickname string for the #MbimContextMediaType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_context_media_type_get_string (MbimContextMediaType val);
GType mbim_context_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_STATE (mbim_context_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_STATE_IS_ENUM__

/**
 * mbim_context_state_get_string:
 * @val: a MbimContextState.
 *
 * Gets the nickname string for the #MbimContextState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_context_state_get_string (MbimContextState val);
GType mbim_context_operation_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_OPERATION (mbim_context_operation_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_OPERATION_IS_ENUM__

/**
 * mbim_context_operation_get_string:
 * @val: a MbimContextOperation.
 *
 * Gets the nickname string for the #MbimContextOperation specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_context_operation_get_string (MbimContextOperation val);
GType mbim_mico_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_MICO_MODE (mbim_mico_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_MICO_MODE_IS_ENUM__

/**
 * mbim_mico_mode_get_string:
 * @val: a MbimMicoMode.
 *
 * Gets the nickname string for the #MbimMicoMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_mico_mode_get_string (MbimMicoMode val);
GType mbim_default_pdu_activation_hint_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DEFAULT_PDU_ACTIVATION_HINT (mbim_default_pdu_activation_hint_get_type ())

/* Define type-specific symbols */
#define __MBIM_DEFAULT_PDU_ACTIVATION_HINT_IS_ENUM__

/**
 * mbim_default_pdu_activation_hint_get_string:
 * @val: a MbimDefaultPduActivationHint.
 *
 * Gets the nickname string for the #MbimDefaultPduActivationHint specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_default_pdu_activation_hint_get_string (MbimDefaultPduActivationHint val);
GType mbim_ladn_info_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_LADN_INFO (mbim_ladn_info_get_type ())

/* Define type-specific symbols */
#define __MBIM_LADN_INFO_IS_ENUM__

/**
 * mbim_ladn_info_get_string:
 * @val: a MbimLadnInfo.
 *
 * Gets the nickname string for the #MbimLadnInfo specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_ladn_info_get_string (MbimLadnInfo val);
GType mbim_drx_cycle_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_DRX_CYCLE (mbim_drx_cycle_get_type ())

/* Define type-specific symbols */
#define __MBIM_DRX_CYCLE_IS_ENUM__

/**
 * mbim_drx_cycle_get_string:
 * @val: a MbimDrxCycle.
 *
 * Gets the nickname string for the #MbimDrxCycle specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_drx_cycle_get_string (MbimDrxCycle val);
GType mbim_quectel_radio_switch_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QUECTEL_RADIO_SWITCH_STATE (mbim_quectel_radio_switch_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_QUECTEL_RADIO_SWITCH_STATE_IS_ENUM__

/**
 * mbim_quectel_radio_switch_state_get_string:
 * @val: a MbimQuectelRadioSwitchState.
 *
 * Gets the nickname string for the #MbimQuectelRadioSwitchState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.26.2
 */
const gchar *mbim_quectel_radio_switch_state_get_string (MbimQuectelRadioSwitchState val);
GType mbim_quectel_command_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QUECTEL_COMMAND_TYPE (mbim_quectel_command_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_QUECTEL_COMMAND_TYPE_IS_ENUM__

/**
 * mbim_quectel_command_type_get_string:
 * @val: a MbimQuectelCommandType.
 *
 * Gets the nickname string for the #MbimQuectelCommandType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.32
 */
const gchar *mbim_quectel_command_type_get_string (MbimQuectelCommandType val);
GType mbim_quectel_command_response_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_QUECTEL_COMMAND_RESPONSE_STATUS (mbim_quectel_command_response_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_QUECTEL_COMMAND_RESPONSE_STATUS_IS_ENUM__

/**
 * mbim_quectel_command_response_status_get_string:
 * @val: a MbimQuectelCommandResponseStatus.
 *
 * Gets the nickname string for the #MbimQuectelCommandResponseStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.32
 */
const gchar *mbim_quectel_command_response_status_get_string (MbimQuectelCommandResponseStatus val);
GType mbim_intel_serving_cell_info_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_INTEL_SERVING_CELL_INFO (mbim_intel_serving_cell_info_get_type ())

/* Define type-specific symbols */
#define __MBIM_INTEL_SERVING_CELL_INFO_IS_ENUM__

/**
 * mbim_intel_serving_cell_info_get_string:
 * @val: a MbimIntelServingCellInfo.
 *
 * Gets the nickname string for the #MbimIntelServingCellInfo specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_intel_serving_cell_info_get_string (MbimIntelServingCellInfo val);
GType mbim_intel_boot_mode_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_INTEL_BOOT_MODE (mbim_intel_boot_mode_get_type ())

/* Define type-specific symbols */
#define __MBIM_INTEL_BOOT_MODE_IS_ENUM__

/**
 * mbim_intel_boot_mode_get_string:
 * @val: a MbimIntelBootMode.
 *
 * Gets the nickname string for the #MbimIntelBootMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_intel_boot_mode_get_string (MbimIntelBootMode val);
GType mbim_uicc_application_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_APPLICATION_TYPE (mbim_uicc_application_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_APPLICATION_TYPE_IS_ENUM__

/**
 * mbim_uicc_application_type_get_string:
 * @val: a MbimUiccApplicationType.
 *
 * Gets the nickname string for the #MbimUiccApplicationType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_uicc_application_type_get_string (MbimUiccApplicationType val);
GType mbim_uicc_file_accessibility_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_FILE_ACCESSIBILITY (mbim_uicc_file_accessibility_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_FILE_ACCESSIBILITY_IS_ENUM__

/**
 * mbim_uicc_file_accessibility_get_string:
 * @val: a MbimUiccFileAccessibility.
 *
 * Gets the nickname string for the #MbimUiccFileAccessibility specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_uicc_file_accessibility_get_string (MbimUiccFileAccessibility val);
GType mbim_uicc_file_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_FILE_TYPE (mbim_uicc_file_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_FILE_TYPE_IS_ENUM__

/**
 * mbim_uicc_file_type_get_string:
 * @val: a MbimUiccFileType.
 *
 * Gets the nickname string for the #MbimUiccFileType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_uicc_file_type_get_string (MbimUiccFileType val);
GType mbim_uicc_file_structure_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_UICC_FILE_STRUCTURE (mbim_uicc_file_structure_get_type ())

/* Define type-specific symbols */
#define __MBIM_UICC_FILE_STRUCTURE_IS_ENUM__

/**
 * mbim_uicc_file_structure_get_string:
 * @val: a MbimUiccFileStructure.
 *
 * Gets the nickname string for the #MbimUiccFileStructure specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_uicc_file_structure_get_string (MbimUiccFileStructure val);
GType mbim_trace_command_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_TRACE_COMMAND (mbim_trace_command_get_type ())

/* Define type-specific symbols */
#define __MBIM_TRACE_COMMAND_IS_ENUM__

/**
 * mbim_trace_command_get_string:
 * @val: a MbimTraceCommand.
 *
 * Gets the nickname string for the #MbimTraceCommand specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_trace_command_get_string (MbimTraceCommand val);
GType mbim_carrier_lock_status_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CARRIER_LOCK_STATUS (mbim_carrier_lock_status_get_type ())

/* Define type-specific symbols */
#define __MBIM_CARRIER_LOCK_STATUS_IS_ENUM__

/**
 * mbim_carrier_lock_status_get_string:
 * @val: a MbimCarrierLockStatus.
 *
 * Gets the nickname string for the #MbimCarrierLockStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_carrier_lock_status_get_string (MbimCarrierLockStatus val);
GType mbim_carrier_lock_modem_state_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CARRIER_LOCK_MODEM_STATE (mbim_carrier_lock_modem_state_get_type ())

/* Define type-specific symbols */
#define __MBIM_CARRIER_LOCK_MODEM_STATE_IS_ENUM__

/**
 * mbim_carrier_lock_modem_state_get_string:
 * @val: a MbimCarrierLockModemState.
 *
 * Gets the nickname string for the #MbimCarrierLockModemState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_carrier_lock_modem_state_get_string (MbimCarrierLockModemState val);
GType mbim_carrier_lock_cause_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CARRIER_LOCK_CAUSE (mbim_carrier_lock_cause_get_type ())

/* Define type-specific symbols */
#define __MBIM_CARRIER_LOCK_CAUSE_IS_ENUM__

/**
 * mbim_carrier_lock_cause_get_string:
 * @val: a MbimCarrierLockCause.
 *
 * Gets the nickname string for the #MbimCarrierLockCause specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.30
 */
const gchar *mbim_carrier_lock_cause_get_string (MbimCarrierLockCause val);

/* enumerations from "../libmbim-1.34.0/src/libmbim-glib/mbim-message.h" */
GType mbim_message_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_MESSAGE_TYPE (mbim_message_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_MESSAGE_TYPE_IS_ENUM__

/**
 * mbim_message_type_get_string:
 * @val: a MbimMessageType.
 *
 * Gets the nickname string for the #MbimMessageType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_message_type_get_string (MbimMessageType val);
GType mbim_message_command_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_MESSAGE_COMMAND_TYPE (mbim_message_command_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_MESSAGE_COMMAND_TYPE_IS_ENUM__

/**
 * mbim_message_command_type_get_string:
 * @val: a MbimMessageCommandType.
 *
 * Gets the nickname string for the #MbimMessageCommandType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_message_command_type_get_string (MbimMessageCommandType val);

/* enumerations from "../libmbim-1.34.0/src/libmbim-glib/mbim-tlv.h" */
GType mbim_tlv_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_TLV_TYPE (mbim_tlv_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_TLV_TYPE_IS_ENUM__

/**
 * mbim_tlv_type_get_string:
 * @val: a MbimTlvType.
 *
 * Gets the nickname string for the #MbimTlvType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.28
 */
const gchar *mbim_tlv_type_get_string (MbimTlvType val);

/* enumerations from "../libmbim-1.34.0/src/libmbim-glib/mbim-uuid.h" */
GType mbim_service_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_SERVICE (mbim_service_get_type ())

/* Define type-specific symbols */
#define __MBIM_SERVICE_IS_ENUM__

/**
 * mbim_service_get_string:
 * @val: a MbimService.
 *
 * Gets the nickname string for the #MbimService specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_service_get_string (MbimService val);
GType mbim_context_type_get_type (void) G_GNUC_CONST;
#define MBIM_TYPE_CONTEXT_TYPE (mbim_context_type_get_type ())

/* Define type-specific symbols */
#define __MBIM_CONTEXT_TYPE_IS_ENUM__

/**
 * mbim_context_type_get_string:
 * @val: a MbimContextType.
 *
 * Gets the nickname string for the #MbimContextType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 *
 * Since: 1.0
 */
const gchar *mbim_context_type_get_string (MbimContextType val);
G_END_DECLS

#endif /* __LIBMBIM_GLIB_ENUM_TYPES_H__ */

/* Generated data ends here */

